@@ -1,7 +1,7 @@
 // ===========================================================================
 // File: "criteria.h"
 //                        Created: 2010-04-26 08:31:04
-//              Last modification: 2013-04-22 16:53:17
+//              Last modification: 2013-06-12 15:54:59
 // Author: Bernard Desgraupes
 // e-mail: <bernard.desgraupes@u-paris10.fr>
 // This is part of the R package 'clusterCrit'.
@@ -25,6 +25,8 @@ SEXP	cluc_calculateConcordances(SEXP inPart1, SEXP inPart2);
 
 void	cluc_errorMsg(int inErr);
 
+int		cluc_getIndexFromName(const char * inName, const char **tablePtr);
+
 
 // Fortran routines
 // ----------------
@@ -38,11 +40,11 @@ void F77_NAME(cluc_calc_ext_start)(int* inRows, int* inNbClust1, int* inNbClust2
 void F77_NAME(cluc_calc_ext_end)();
 
 void F77_NAME(cluc_count_clusters)(int* a, int* n, int* result);
-void F77_NAME(cluc_int_set_flags)(int* inLen, const char * critName);
+void F77_NAME(cluc_int_set_flags)(int* inIndex);
 void F77_NAME(cluc_int_precalc)(double* inTraj, int* inPart, int* outErr);
 
-void F77_NAME(cluc_calc_int_criterion)(double* inTraj, int* inPart, int* inLen, const char * critName, int* outErr, double* outRes);
-void F77_NAME(cluc_calc_ext_criterion)(int* inPart1, int* inPart2, int* inLen, const char * critName, int* outErr, double* outRes);
+void F77_NAME(cluc_calc_int_criterion)(double* inTraj, int* inPart, int* inIndex, int* outErr, double* outRes);
+void F77_NAME(cluc_calc_ext_criterion)(int* inPart1, int* inPart2, int* inIndex, int* outErr, double* outRes);
 
 void F77_NAME(cluc_calc_concordance)(int* inPart1, int* inPart2, int* inRows, int confMat[2][2]);
 
